@@ -5,6 +5,7 @@ use CallBackery::Exception qw(mkerror);
 use Mojo::Promise;
 use Mojo::JSON qw(encode_json);
 use Mojo::Util qw(dumper);
+use Time::HiRes;
 
 =head1 NAME
 
@@ -162,7 +163,10 @@ sub getFieldValue {
     return undef unless ref $entry eq 'HASH';
     if ($entry->{getter}){
         if (ref $entry->{getter} eq 'CODE'){
-            return $entry->{getter}->($self);
+            my $start = time();
+            my $data = $entry->{getter}->($self);
+            $self->log->debug(sprintf("ran getter %s: %0.2fs",$field,time()-$start));
+            return $data'
         }
         else {
             $self->log->warn('Plugin instance'.$self->name." field $field has a broken getter\n");
